==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/ServiceCatalog/DisassociatePrincipalFromPortfolio.pm <==

package Paws::ServiceCatalog::DisassociatePrincipalFromPortfolio;
  use Moose;
  has AcceptLanguage => (is => 'ro', isa => 'Str');
  has PortfolioId => (is => 'ro', isa => 'Str', required => 1);
  has PrincipalARN => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociatePrincipalFromPortfolio');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ServiceCatalog::DisassociatePrincipalFromPortfolioOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ServiceCatalog::DisassociatePrincipalFromPortfolio - Arguments for method DisassociatePrincipalFromPortfolio on Paws::ServiceCatalog

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociatePrincipalFromPortfolio on the 
AWS Service Catalog service. Use the attributes of this class
as arguments to method DisassociatePrincipalFromPortfolio.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociatePrincipalFromPortfolio.

As an example:

  $service_obj->DisassociatePrincipalFromPortfolio(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 AcceptLanguage => Str

The language code to use for this operation. Supported language codes
are as follows:

"en" (English)

"jp" (Japanese)

"zh" (Chinese)

If no code is specified, "en" is used as the default.



=head2 B<REQUIRED> PortfolioId => Str

The portfolio identifier.



=head2 B<REQUIRED> PrincipalARN => Str

The ARN representing the principal (IAM user, role, or group).




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociatePrincipalFromPortfolio in L<Paws::ServiceCatalog>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/ServiceCatalog/DisassociatePrincipalFromPortfolio.pm <==

package Paws::ServiceCatalog::DisassociatePrincipalFromPortfolio;
  use Moose;
  has AcceptLanguage => (is => 'ro', isa => 'Str');
  has PortfolioId => (is => 'ro', isa => 'Str', required => 1);
  has PrincipalARN => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociatePrincipalFromPortfolio');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ServiceCatalog::DisassociatePrincipalFromPortfolioOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ServiceCatalog::DisassociatePrincipalFromPortfolio - Arguments for method DisassociatePrincipalFromPortfolio on Paws::ServiceCatalog

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociatePrincipalFromPortfolio on the 
AWS Service Catalog service. Use the attributes of this class
as arguments to method DisassociatePrincipalFromPortfolio.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociatePrincipalFromPortfolio.

As an example:

  $service_obj->DisassociatePrincipalFromPortfolio(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 AcceptLanguage => Str

The language code.

=over

=item *

C<en> - English (default)

=item *

C<jp> - Japanese

=item *

C<zh> - Chinese

=back




=head2 B<REQUIRED> PortfolioId => Str

The portfolio identifier.



=head2 B<REQUIRED> PrincipalARN => Str

The ARN representing the principal (IAM user, role, or group).




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociatePrincipalFromPortfolio in L<Paws::ServiceCatalog>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
